@@ -3,7 +3,7 @@ import inspect
 import asyncio
 import functools
 import discord
-import emoji as em
+from deprecated import deprecated
 
 
 def is_coroutine_function_or_partial(obj):
@@ -12,6 +12,7 @@ def is_coroutine_function_or_partial(obj):
     return inspect.iscoroutinefunction(obj)
 
 
+@deprecated(version='1.4', reason="Rewritten under create_machine_utils.minidiscord.menu.Menu, please use that instead")
 class Menu:
     def __init__(self, bot, timeout: int = 60, callbacks: bool = False,
                  timeout_callback: typing.Union[typing.Callable, typing.Coroutine] = None):
@@ -25,7 +26,7 @@ class Menu:
         async def add_reactions():
             for react in self.__reactions.keys():
                 try:
-                    await message.add_reaction(em.demojize(em.emojize(react, use_aliases=True)))
+                    await message.add_reaction(react, use_aliases=True)
                 except discord.HTTPException as e:
                     print(f"Couldn't add {react} - {e}")
                     pass
